:mod:`art.wrappers`
===================
.. automodule:: art.wrappers

Base Class Wrapper
------------------
.. autoclass:: ClassifierWrapper
   :members:

Expectation over Transformations
--------------------------------
.. autoclass:: ExpectationOverTransformations
   :members:

Query-Efficient Black-Box Attack
--------------------------------
.. autoclass:: QueryEfficientBBGradientEstimation
   :members:
